Fix a latent bug in MinimalActions (created by a recent name change).


git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@42829 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/Driver/PrintParserCallbacks.cpp b/Driver/PrintParserCallbacks.cpp
index e3bfdf5..d7deb43 100644
--- a/Driver/PrintParserCallbacks.cpp
+++ b/Driver/PrintParserCallbacks.cpp
@@ -38,13 +38,13 @@
       return MinimalAction::ActOnDeclarator(S, D, LastInGroup);
     }
     
-    /// PopScope - This callback is called immediately before the specified scope
-    /// is popped and deleted.
-    virtual void PopScope(SourceLocation Loc, Scope *S) {
-      std::cout << "PopScope\n";
+    /// ActOnPopScope - This callback is called immediately before the specified
+    /// scope is popped and deleted.
+    virtual void ActOnPopScope(SourceLocation Loc, Scope *S) {
+      std::cout << "ActOnPopScope\n";
       
       // Pass up to EmptyActions so that the symbol table is maintained right.
-      MinimalAction::PopScope(Loc, S);
+      MinimalAction::ActOnPopScope(Loc, S);
     }
   };
 }
diff --git a/Parse/MinimalAction.cpp b/Parse/MinimalAction.cpp
index 932f8ff..b0dad93 100644
--- a/Parse/MinimalAction.cpp
+++ b/Parse/MinimalAction.cpp
@@ -97,9 +97,9 @@
   return 0;
 }
 
 /// PopScope - When a scope is popped, if any typedefs are now out-of-scope,
 /// they are removed from the IdentifierInfo::FETokenInfo field.
-void MinimalAction::PopScope(SourceLocation Loc, Scope *S) {
+void MinimalAction::ActOnPopScope(SourceLocation Loc, Scope *S) {
   for (Scope::decl_iterator I = S->decl_begin(), E = S->decl_end();
        I != E; ++I) {
     IdentifierInfo &II = *static_cast<IdentifierInfo*>(*I);
@@ -97,9 +97,9 @@
 }
 
-/// PopScope - When a scope is popped, if any typedefs are now out-of-scope,
+/// ActOnPopScope - When a scope is popped, if any typedefs are now out-of-scope,
 /// they are removed from the IdentifierInfo::FETokenInfo field.
diff --git a/include/clang/Parse/Action.h b/include/clang/Parse/Action.h
index 89ed0c6..b5142f0 100644
--- a/include/clang/Parse/Action.h
+++ b/include/clang/Parse/Action.h
@@ -597,9 +597,9 @@
   /// popped.
   virtual DeclTy *ActOnDeclarator(Scope *S, Declarator &D, DeclTy *LastInGroup);
   
-  /// PopScope - When a scope is popped, if any typedefs are now out-of-scope,
-  /// they are removed from the IdentifierInfo::FETokenInfo field.
-  virtual void PopScope(SourceLocation Loc, Scope *S);
+  /// ActOnPopScope - When a scope is popped, if any typedefs are now 
+  /// out-of-scope, they are removed from the IdentifierInfo::FETokenInfo field.
+  virtual void ActOnPopScope(SourceLocation Loc, Scope *S);
   virtual void ActOnTranslationUnitScope(SourceLocation Loc, Scope *S) {
     TUScope = S;
   }